@@ -12,8 +12,8 @@ EV - perl interface to libev, a high performance full-featured event loop
       warn "is called after 2s";
    };
    
-   my $w = EV::timer 0, 3, sub {
-      warn "is called as soon as possible, then every 3s";
+   my $w = EV::timer 2, 2, sub {
+      warn "is called roughly every 2s (repeat = 2)";
    };
    
    undef $w; # destroy event watcher again
@@ -37,7 +37,7 @@ EV - perl interface to libev, a high performance full-featured event loop
    
    # CHILD/PID STATUS CHANGES
   
-   my $w = EV::child $pid, 0, sub {
+   my $w = EV::child 666, 0, sub {
       my ($w, $revents) = @_;
       my $status = $w->rstatus;
    };
@@ -49,9 +49,9 @@ EV - perl interface to libev, a high performance full-featured event loop
    };
    
    # MAINLOOP
-   EV::run;                # loop until EV::break is called or all watchers stop
-   EV::run EV::RUN_ONCE;   # block until at least one event could be handled
-   EV::run EV::RUN_NOWAIT; # try to handle same events, but do not block
+   EV::loop;           # loop until EV::unloop is called or all watchers stop
+   EV::loop EV::LOOP_ONESHOT;  # block until at least one event could be handled
+   EV::loop EV::LOOP_NONBLOCK; # try to handle same events, but do not block
 
 =head1 BEFORE YOU START USING THIS MODULE
 
@@ -121,11 +121,9 @@ package EV;
 use common::sense;
 
 BEGIN {
-   our $VERSION = '4.34_002';
+   our $VERSION = '4.01';
    use XSLoader;
-   local $^W = 0; # avoid spurious warning
    XSLoader::load "EV", $VERSION;
-   $VERSION =~ tr/_//d;
 }
 
 @EV::IO::ISA       =
@@ -178,7 +176,7 @@ or locally-installed as F<EV::libev> manpage) for more info.
 The loop will automatically be destroyed when it is no longer referenced
 by any watcher and the loop object goes out of scope.
 
-If you are not embedding the loop, then using C<EV::FLAG_FORKCHECK>
+If you are not embedding the loop, then Using C<EV::FLAG_FORKCHECK>
 is recommended, as only the default event loop is protected by this
 module. If you I<are> embedding this loop in the default loop, this is not
 necessary, as C<EV::embed> automatically does the right thing on fork.
@@ -190,7 +188,7 @@ the event loop. An alternative is to use C<EV::FLAG_FORKCHECK> which calls
 this function automatically, at some performance loss (refer to the libev
 documentation).
 
-=item $loop->verify
+=item $loop->loop_verify
 
 Calls C<ev_verify> to make internal consistency checks (for debugging
 libev) and abort the program if any data structures were found to be
@@ -251,7 +249,7 @@ usually faster then calling EV::time.
 
 Establishes the current time by querying the kernel, updating the time
 returned by C<EV::now> in the progress. This is a costly operation and
-is usually done automatically within C<EV::run>.
+is usually done automatically within C<EV::loop>.
 
 This function is rarely useful, but when some event callback runs for a
 very long time without entering the event loop, updating libev's idea of
@@ -294,39 +292,32 @@ loop time (see C<now_update>).
 Returns an integer describing the backend used by libev (EV::BACKEND_SELECT
 or EV::BACKEND_EPOLL).
 
-=item $active = EV::run [$flags]
+=item EV::loop [$flags]
 
-=item $active = $loop->run ([$flags])
+=item $loop->loop ([$flags])
 
 Begin checking for events and calling callbacks. It returns when a
-callback calls EV::break or the flags are nonzero (in which case the
-return value is true) or when there are no active watchers which reference
-the loop (keepalive is true), in which case the return value will be
-false. The return value can generally be interpreted as "if true, there is
-more work left to do".
+callback calls EV::unloop.
 
 The $flags argument can be one of the following:
 
-   0               as above
-   EV::RUN_ONCE    block at most once (wait, but do not loop)
-   EV::RUN_NOWAIT  do not block at all (fetch/handle events but do not wait)
+   0                  as above
+   EV::LOOP_ONESHOT   block at most once (wait, but do not loop)
+   EV::LOOP_NONBLOCK  do not block at all (fetch/handle events but do not wait)
 
-=item EV::break [$how]
+=item EV::unloop [$how]
 
-=item $loop->break ([$how])
+=item $loop->unloop ([$how])
 
-When called with no arguments or an argument of EV::BREAK_ONE, makes the
-innermost call to EV::run return.
+When called with no arguments or an argument of EV::UNLOOP_ONE, makes the
+innermost call to EV::loop return.
 
-When called with an argument of EV::BREAK_ALL, all calls to EV::run will
-return as fast as possible.
+When called with an argument of EV::UNLOOP_ALL, all calls to EV::loop will return as
+fast as possible.
 
-When called with an argument of EV::BREAK_CANCEL, any pending break will
-be cancelled.
+=item $count = EV::loop_count
 
-=item $count = EV::iteration
-
-=item $count = $loop->iteration
+=item $count = $loop->loop_count
 
 Return the number of times the event loop has polled for new
 events. Sometimes useful as a generation counter.
@@ -345,7 +336,7 @@ you do not want to wait for some I/O event, specify C<undef> for
 C<$fh_or_undef> and C<0> for C<$events>).
 
 If timeout is C<undef> or negative, then there will be no
-timeout. Otherwise an C<EV::timer> with this value will be started.
+timeout. Otherwise a EV::timer with this value will be started.
 
 When an error occurs or either the timeout or I/O watcher triggers, then
 the callback will be called with the received event set (in general
@@ -356,7 +347,7 @@ EV::once doesn't return anything: the watchers stay active till either
 of them triggers, then they will be stopped and freed, and the callback
 invoked.
 
-=item EV::feed_fd_event $fd, $revents
+=item EV::feed_fd_event ($fd, $revents)
 
 =item $loop->feed_fd_event ($fd, $revents)
 
@@ -364,16 +355,10 @@ Feed an event on a file descriptor into EV. EV will react to this call as
 if the readyness notifications specified by C<$revents> (a combination of
 C<EV::READ> and C<EV::WRITE>) happened on the file descriptor C<$fd>.
 
-=item EV::feed_signal_event $signal
+=item EV::feed_signal_event ($signal)
 
-Feed a signal event into the default loop. EV will react to this call as
-if the signal specified by C<$signal> had occured.
-
-=item EV::feed_signal $signal
-
-Feed a signal event into EV - unlike C<EV::feed_signal_event>, this works
-regardless of which loop has registered the signal, and is mainly useful
-for custom signal implementations.
+Feed a signal event into EV. EV will react to this call as if the signal
+specified by C<$signal> had occured.
 
 =item EV::set_io_collect_interval $time
 
@@ -510,21 +495,21 @@ watcher isn't pending it does nothing and returns C<0>.
 
 =item $previous_state = $w->keepalive ($bool)
 
-Normally, C<EV::run> will return when there are no active watchers
+Normally, C<EV::loop> will return when there are no active watchers
 (which is a "deadlock" because no progress can be made anymore). This is
 convenient because it allows you to start your watchers (and your jobs),
-call C<EV::run> once and when it returns you know that all your jobs are
+call C<EV::loop> once and when it returns you know that all your jobs are
 finished (or they forgot to register some watchers for their task :).
 
 Sometimes, however, this gets in your way, for example when the module
-that calls C<EV::run> (usually the main program) is not the same module
+that calls C<EV::loop> (usually the main program) is not the same module
 as a long-living watcher (for example a DNS client module written by
 somebody else even). Then you might want any outstanding requests to be
-handled, but you would not want to keep C<EV::run> from returning just
+handled, but you would not want to keep C<EV::loop> from returning just
 because you happen to have this long-running UDP port watcher.
 
 In this case you can clear the keepalive status, which means that even
-though your watcher is active, it won't keep C<EV::run> from returning.
+though your watcher is active, it won't keep C<EV::loop> from returning.
 
 The initial value for keepalive is true (enabled), and you can change it
 any time.
@@ -601,9 +586,9 @@ Returns the previously set event mask and optionally set a new one.
 
 =item $w = $loop->timer_ns ($after, $repeat, $callback)
 
-Calls the callback after C<$after> seconds (which may be fractional or
-negative). If C<$repeat> is non-zero, the timer will be restarted (with
-the $repeat value as $after) after the callback returns.
+Calls the callback after C<$after> seconds (which may be fractional). If
+C<$repeat> is non-zero, the timer will be restarted (with the $repeat
+value as $after) after the callback returns.
 
 This means that the callback would be called roughly after C<$after>
 seconds, and then every C<$repeat> seconds. The timer does his best not
@@ -617,15 +602,13 @@ clock, the timer will nevertheless run (roughly) the same time.
 
 The C<timer_ns> variant doesn't start (activate) the newly created watcher.
 
-=item $w->set ($after, $repeat = 0)
+=item $w->set ($after, $repeat)
 
 Reconfigures the watcher, see the constructor above for details. Can be called at
 any time.
 
 =item $w->again
 
-=item $w->again ($repeat)
-
 Similar to the C<start> method, but has special semantics for repeating timers:
 
 If the timer is active and non-repeating, it will be stopped.
@@ -642,21 +625,6 @@ operation. You create a timer object with the same value for C<$after> and
 C<$repeat>, and then, in the read/write watcher, run the C<again> method
 on the timeout.
 
-If called with a C<$repeat> argument, then it uses this a timer repeat
-value.
-
-=item $after = $w->remaining
-
-Calculates and returns the remaining time till the timer will fire.
-
-=item $repeat = $w->repeat
-
-=item $old_repeat = $w->repeat ($new_repeat)
-
-Returns the current value of the repeat attribute and optionally sets a
-new one. Setting the new one will not restart the watcher - if the watcher
-is active, the new repeat value is used whenever it expires next.
-
 =back
 
 
@@ -693,9 +661,8 @@ surpasses this time.
 =item * repeating interval timer ($interval > 0, $reschedule_cb = 0)
 
 In this mode the watcher will always be scheduled to time out at the
-next C<$at + N * $interval> time (for the lowest integer N) and then repeat,
-regardless of any time jumps. Note that, since C<N> can be negative, the
-first trigger can happen before C<$at>.
+next C<$at + N * $interval> time (for some integer N) and then repeat,
+regardless of any time jumps.
 
 This can be used to create timers that do not drift with respect to system
 time:
@@ -703,7 +670,7 @@ time:
    my $hourly = EV::periodic 0, 3600, 0, sub { print "once/hour\n" };
 
 That doesn't mean there will always be 3600 seconds in between triggers,
-but only that the the callback will be called when the system time shows a
+but only that the the clalback will be called when the system time shows a
 full hour (UTC).
 
 Another way to think about it (for the mathematically inclined) is that
@@ -721,7 +688,7 @@ time as second argument.
 I<This callback MUST NOT stop or destroy this or any other periodic
 watcher, ever, and MUST NOT call any event loop functions or methods>. If
 you need to stop it, return 1e30 and stop it afterwards. You may create
-and start an C<EV::prepare> watcher for this task.
+and start a C<EV::prepare> watcher for this task.
 
 It must return the next time to trigger, based on the passed time value
 (that is, the lowest time value larger than or equal to to the second
@@ -729,15 +696,17 @@ argument). It will usually be called just before the callback will be
 triggered, but might be called at other times, too.
 
 This can be used to create very complex timers, such as a timer that
-triggers on each midnight, local time (actually one day after the last
-midnight, to keep the example simple):
+triggers on each midnight, local time (actually 24 hours after the last
+midnight, to keep the example simple. If you know a way to do it correctly
+in about the same space (without requiring elaborate modules), drop me a
+note :):
 
    my $daily = EV::periodic 0, 0, sub {
       my ($w, $now) = @_;
 
       use Time::Local ();
       my (undef, undef, undef, $d, $m, $y) = localtime $now;
-      Time::Local::timelocal_nocheck 0, 0, 0, $d + 1, $m, $y
+      86400 + Time::Local::timelocal 0, 0, 0, $d, $m, $y
    }, sub {
       print "it's midnight or likely shortly after, now\n";
    };
@@ -759,26 +728,6 @@ Simply stops and starts the watcher again.
 
 Return the time that the watcher is expected to trigger next.
 
-=item $offset = $w->offset
-
-=item $old_offset = $w->offset ($new_offset)
-
-Returns the current value of the offset attribute and optionally sets a
-new one. Setting the new one will not restart the watcher - if the watcher
-is active, the new offset value is used whenever it expires next.
-
-=item $interval = $w->interval
-
-=item $old_interval = $w->interval ($new_interval)
-
-See above, for the interval attribute.
-
-=item $reschedule_cb = $w->reschedule_cb
-
-=item $old_reschedule_cb = $w->reschedule_cb ($new_reschedule_cb)
-
-See above, for the reschedule callback.
-
 =back
 
 
@@ -876,17 +825,6 @@ in perlfunc).
 Return the pid of the awaited child (useful when you have installed a
 watcher for all pids).
 
-=item EV::Child::reinit [EXPERIMENTAL]
-
-Internally, libev installs a signal handler for C<SIGCHLD>. Unfortunately,
-a lot of Perl code does soemthing like C<< local $SIG{CHLD} >>, which,
-unfortunately, is broken and will not restore the signal handler.
-
-If this has happened, you can call this function to stop/rrestart the
-internal libev watcher, which will reset the signal handler.
-
-Note that this is an experimental function, whose interface might change.
-
 =back
 
 
@@ -1190,21 +1128,12 @@ Please see the libev documentation for further details.
 
 =item $w = EV::async_ns $callback
 
-=item $w = $loop->async ($callback)
-
-=item $w = $loop->async_ns ($callback)
-
 =item $w->send
 
 =item $bool = $w->async_pending
 
 =back
 
-=head3 CLEANUP WATCHERS - how to clean up when the event loop goes away
-
-Cleanup watchers are not supported on the Perl level, they can only be
-used via XS currently.
-
 
 =head1 PERL SIGNALS
 
